@@ -24,20 +24,15 @@ class Ntp(monasca_setup.detection.Plugin):
         config = monasca_setup.agent_config.Plugins()
         log.info("\tEnabling the ntp plugin")
         if os.path.exists('/etc/ntp.conf'):
+            server = re.compile('server (.*)')
             with open('/etc/ntp.conf', 'r') as ntp_config:
-                ntp_conf = ntp_config.read()
-            match = re.search('^server (.*?)( #|$)', ntp_conf, re.MULTILINE)
+                match = server.search(ntp_config.read())
             if match is None:
                 ntp_server = 'pool.ntp.org'
             else:
-                # There can be additional options after the server hostname or IP Address
-                server_val = match.group(1)
-                ntp_server = server_val.split()[0]
+                ntp_server = match.group(1)
         else:
             ntp_server = 'pool.ntp.org'
-        if re.match('^127', ntp_server):
-            log.warn("NTP Server points to localhost no value in collecting NTP metrics. Skipping configuration.")
-            return None
         config['ntp'] = {'init_config': None, 'instances': [{'name': ntp_server, 'host': ntp_server}]}
 
         return config
